diff --git a/src/Form/LingotekManagementFormBase.php b/src/Form/LingotekManagementFormBase.php
index 6f58a99b..ded4e0ac 100644
--- a/src/Form/LingotekManagementFormBase.php
+++ b/src/Form/LingotekManagementFormBase.php
@@ -231,7 +231,7 @@ abstract class LingotekManagementFormBase extends FormBase {
         '#default_value' => $sourceStatusFilter,
         '#options' => [
           '' => $this->t('All'),
-          'NEEDS_UPLOAD' => $this->t('Needing upload'),
+          'UPLOAD_NEEDED' => $this->t('Upload Needed'),
           Lingotek::STATUS_CURRENT => $this->t('Current'),
           Lingotek::STATUS_IMPORTING => $this->t('Importing'),
           Lingotek::STATUS_EDITED => $this->t('Edited'),
diff --git a/tests/src/Functional/Form/LingotekNodeBulkFormTest.php b/tests/src/Functional/Form/LingotekNodeBulkFormTest.php
index b2460323..975d7f9e 100644
--- a/tests/src/Functional/Form/LingotekNodeBulkFormTest.php
+++ b/tests/src/Functional/Form/LingotekNodeBulkFormTest.php
@@ -1350,7 +1350,7 @@ class LingotekNodeBulkFormTest extends LingotekTestBase {
     $this->assertText('NotConfigured nothing nothing nothing');
 
     $edit = [
-      'filters[advanced_options][source_status]' => 'NEEDS_UPLOAD',
+      'filters[advanced_options][source_status]' => 'UPLOAD_NEEDED',
     ];
     $this->drupalPostForm(NULL, $edit, 'edit-filters-actions-submit');
 
@@ -1368,7 +1368,7 @@ class LingotekNodeBulkFormTest extends LingotekTestBase {
     $this->assertText('NotConfigured nothing nothing nothing');
 
     $edit = [
-      'filters[advanced_options][source_status]' => 'NEEDS_UPLOAD',
+      'filters[advanced_options][source_status]' => 'UPLOAD_NEEDED',
       'filters[wrapper][bundle][]' => ['custom_type', 'not_configured'],
     ];
     $this->drupalPostForm(NULL, $edit, 'edit-filters-actions-submit');
@@ -1387,7 +1387,7 @@ class LingotekNodeBulkFormTest extends LingotekTestBase {
     $this->assertText('NotConfigured nothing nothing nothing');
 
     $edit = [
-      'filters[advanced_options][source_status]' => 'NEEDS_UPLOAD',
+      'filters[advanced_options][source_status]' => 'UPLOAD_NEEDED',
       'filters[wrapper][bundle][]' => ['custom_type', 'not_configured'],
       'filters[advanced_options][source_language]' => 'en',
     ];
@@ -1407,7 +1407,7 @@ class LingotekNodeBulkFormTest extends LingotekTestBase {
     $this->assertText('NotConfigured nothing nothing nothing');
 
     $edit = [
-      'filters[advanced_options][source_status]' => 'NEEDS_UPLOAD',
+      'filters[advanced_options][source_status]' => 'UPLOAD_NEEDED',
       'filters[wrapper][bundle][]' => ['custom_type', 'not_configured'],
       'filters[advanced_options][source_language]' => 'en',
       'filters[advanced_options][profile][]' => ['manual', 'automatic'],
@@ -1428,7 +1428,7 @@ class LingotekNodeBulkFormTest extends LingotekTestBase {
     $this->assertNoText('NotConfigured nothing nothing nothing');
 
     $edit = [
-      'filters[advanced_options][source_status]' => 'NEEDS_UPLOAD',
+      'filters[advanced_options][source_status]' => 'UPLOAD_NEEDED',
       'filters[wrapper][bundle][]' => ['custom_type', 'not_configured'],
       'filters[advanced_options][source_language]' => 'en',
       'filters[advanced_options][profile][]' => ['manual', 'automatic'],

diff --git a/src/Form/LingotekManagementForm.php b/src/Form/LingotekManagementForm.php
index 0bbf67e3..d6b34ab3 100644
--- a/src/Form/LingotekManagementForm.php
+++ b/src/Form/LingotekManagementForm.php
@@ -100,8 +100,8 @@ class LingotekManagementForm extends LingotekManagementFormBase {
     $profileFilter = $temp_store->get('profile');
 
     if ($sourceStatusFilter) {
-      if ($sourceStatusFilter === 'NEEDS_UPLOAD') {
-        // We consider that needing upload includes those never uploaded or
+      if ($sourceStatusFilter === 'UPLOAD_NEEDED') {
+        // We consider that "Upload Needed" includes those never uploaded or
         // disassociated, edited, or with error on last upload.
         $needingUploadStatuses = [
           Lingotek::STATUS_EDITED,